summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMark Adler <madler@alumni.caltech.edu>2021-02-06 00:38:31 -0800
committerMark Adler <madler@alumni.caltech.edu>2021-02-06 00:46:10 -0800
commitb6da942b9ca15eb9149837f07b2b3b6ff21d9845 (patch)
tree32f12acc81b77d28c380422a20149a39b084da19
parent04cb4f31cdfc6cd12b0277332bf6d2160c5f8a2a (diff)
downloadpigz-b6da942b9ca15eb9149837f07b2b3b6ff21d9845.tar.gz
pigz version 2.6upstream/v2.6
-rw-r--r--README2
-rw-r--r--pigz.114
-rw-r--r--pigz.c7
-rw-r--r--pigz.pdfbin10965 -> 11084 bytes
-rw-r--r--pigz.spec2
5 files changed, 17 insertions, 8 deletions
diff --git a/README b/README
index c880cd5..7791744 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-pigz 2.5 (23 Jan 2021) by Mark Adler
+pigz 2.6 (6 Feb 2021) by Mark Adler
pigz, which stands for Parallel Implementation of GZip, is a fully functional
replacement for gzip that exploits multiple processors and multiple cores to
diff --git a/pigz.1 b/pigz.1
index b292fbd..c6a4950 100644
--- a/pigz.1
+++ b/pigz.1
@@ -1,4 +1,4 @@
-.TH PIGZ 1 "January 23, 2021"
+.TH PIGZ 1 "February 6, 2021"
.SH NAME
pigz, unpigz \- compress or expand files
.SH SYNOPSIS
@@ -136,6 +136,9 @@ Set compression block size to mmmK (default 128KiB).
.B -c --stdout --to-stdout
Write all processed output to stdout (won't delete).
.TP
+.B -C --comment ccc
+Include the provided comment in the gzip header or zip central file header.
+.TP
.B -d --decompress --uncompress
Decompress the compressed input.
.TP
@@ -145,6 +148,9 @@ Force overwrite, compress .gz, links, and to terminal.
.B -h --help
Display a help screen and quit.
.TP
+.B -H --huffman
+Compress using the Huffman-only strategy.
+.TP
.B -i --independent
Compress blocks independently for damage recovery.
.TP
@@ -183,9 +189,6 @@ the modification time of the compressed file is used (not the current time).
Store or restore both the file name and the modification time. This is the
default when compressing.
.TP
-.B -C --comment ccc
-Include the provided comment in the gzip header or zip central file header.
-.TP
.B -p --processes n
Allow up to n processes (default is the number of online processors)
.TP
@@ -204,6 +207,9 @@ Use suffix .sss instead of .gz (for compression).
.B -t --test
Test the integrity of the compressed input.
.TP
+.B -U --rle
+Compress using the run length encoding strategy.
+.TP
.B -v --verbose
Provide more verbose output.
.TP
diff --git a/pigz.pdf b/pigz.pdf
index ae52a17..d44da23 100644
--- a/pigz.pdf
+++ b/pigz.pdf
Binary files differ
diff --git a/pigz.spec b/pigz.spec
index 955e197..5ebd1ac 100644
--- a/pigz.spec
+++ b/pigz.spec
@@ -1,6 +1,6 @@
Summary: pigz is a parallel implementation of gzip which utilizes multiple cores
Name: pigz
-Version: 2.5
+Version: 2.6
Release: 1
Source0: %{name}-%{version}.tar.gz
License: zlib
diff --git a/pigz.c b/pigz.c
index 7a97692..f90157f 100644
--- a/pigz.c
+++ b/pigz.c
@@ -1,6 +1,6 @@
/* pigz.c -- parallel implementation of gzip
* Copyright (C) 2007-2021 Mark Adler
* Version 2.5 23 Jan 2021 Mark Adler
*/
/*
@@ -195,9 +195,12 @@
Do not reject .zip entries with bit 11 set
Avoid a possible threads lock-order inversion
Ignore trailing junk after a gzip stream by default
+ 2.6 6 Feb 2021 Add --huffman/-H and --rle/U strategy options
+ Fix issue when compiling for no threads
+ Fail silently on a broken pipe
*/
-#define VERSION "pigz 2.5"
+#define VERSION "pigz 2.6"
/* To-do:
- make source portable for Windows, VMS, etc. (see gzip source code)
@@ -1,6 +1,6 @@
/* pigz.c -- parallel implementation of gzip
* Copyright (C) 2007-2021 Mark Adler
- * Version 2.5 23 Jan 2021 Mark Adler
+ * Version 2.6 6 Feb 2021 Mark Adler
*/
/*